@@ -12,6 +12,10 @@ class BasicFormView(FormView):
     email_recipients = None
     email_subject = 'Contact Form'
 
+    def get_email_recipients(self, form):
+        # Default to managers if no recipients are specified
+        return self.email_recipients or [x[1] for x in settings.MANAGERS]
+
     def form_valid(self, form):
         # Build up the email here, so any number of fields can be added
         form_data = []
@@ -21,9 +25,7 @@ class BasicFormView(FormView):
 
         body = '\n'.join(form_data)
         subject = u'%s%s' % (settings.EMAIL_SUBJECT_PREFIX, self.email_subject)
-
-        # Default to managers if no recipients are specified
-        recipients = self.email_recipients or [x[1] for x in settings.MANAGERS]
+        recipients = self.get_email_recipients(form)
 
         # We open a connection and send multiple mails for recipient privacy
         connection = mail.get_connection()
